"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
class Gracchi {
    constructor({ key, url }) {
        this.key = key;
        this.url = url;
    }
    // async trades({ base, quote }: { base: string; quote: string }) {
    //   return this._call(
    //     "/v1/trades",
    //     "GET",
    //     {
    //       base,
    //       quote,
    //     },
    //     false
    //   );
    // }
    orderbook({ base, quote }) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call("/v1/orderbook", "GET", {
                base,
                quote,
            }, false);
        });
    }
    ticker({ base, quote }) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call("/v1/ticker", "GET", { base, quote }, false);
        });
    }
    // async myTrades(params) {
    //   params = await Schemas.myTradesSchema.validateAsync(params);
    //   return this._call("/v1/myTrades", "GET", {}, true);
    // }
    cancelOrder({ orderId }) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call(`/v1/trade/orders/${orderId}`, "DELETE", null, true);
        });
    }
    getOrder({ orderId }) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call(`/v1/trade/orders/${orderId}`, "GET", null, true);
        });
    }
    placeOrder({ base, quote, price, amount, side }) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call("/v1/trade/orders", "POST", {
                base,
                quote,
                price,
                amount,
                side,
            }, true);
        });
    }
    balance() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._call("/v1/account/balances", "GET", null, true);
        });
    }
    _call(endpoint, method, params = {}, auth = false) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const config = {
                    method: method,
                    url: `${this.url}${endpoint}`,
                };
                if (method === "GET") {
                    config.params = params;
                }
                else if (method === "POST" || method === "PATCH") {
                    config.data = params;
                }
                if (auth) {
                    config.headers.authentication = this.key;
                }
                const { data } = yield axios_1.default(config);
                return data.response;
            }
            catch (error) {
                throw ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) || ((_c = error === null || error === void 0 ? void 0 : error.response) === null || _c === void 0 ? void 0 : _c.data) || error;
            }
        });
    }
}
exports.default = Gracchi;
